package org.rcisoft.business.bmessage.service.impl;

import org.rcisoft.core.util.UserUtil;
import org.rcisoft.core.aop.PageUtil;
import org.rcisoft.core.model.PersistModel;
import org.rcisoft.business.bmessage.dao.BMessageRepository;
import org.rcisoft.business.bmessage.entity.BMessage;
import org.rcisoft.business.bmessage.service.BMessageService;


import org.rcisoft.sys.user.bean.CurUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import lombok.extern.slf4j.Slf4j;

/**
 * Created by  on 2019-11-25 10:55:03.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BMessageServiceImpl implements BMessageService {

    @Autowired
    private BMessageRepository bMessageRepository;


    /**
    * 保存 bMessage
    * @param bMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel save(BMessage bMessage){
        //增加操作
        UserUtil.setCurrentPersistOperation(bMessage);
        int line = bMessageRepository.insertSelective(bMessage);
        return new PersistModel(line);
    }

    /**
    * 逻辑删除
    * @param bMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel remove(BMessage bMessage){
        UserUtil.setCurrentMergeOperation(bMessage);
        bMessage.setDeleted();
        int line = bMessageRepository.logicalDelete(bMessage);
        return new PersistModel(line);
    }

    /**
    * 修改 bMessage
    * @param bMessage
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public PersistModel merge(BMessage bMessage){
        UserUtil.setCurrentMergeOperation(bMessage);
        int line = bMessageRepository.updateByPrimaryKeySelective(bMessage);
        return new PersistModel(line);
    }

    /**
    * 根据id查询 bMessage
    * @param id
    * @return
    */
    public BMessage findById(String id){
        return bMessageRepository.selectByPrimaryKey(id);
    }

    @Override
    public List<BMessage> findAll(CurUser curUser) {
        return bMessageRepository.queryBMessages(curUser);
    }

//    /**
//    * 分页查询 bMessage
//    * @param bMessage
//    * @return
//    */
//    public List<BMessage> findAllByPagination(PageUtil<BMessage> paginationUtility,
//        BMessage bMessage){
//        bMessage.setStart();
//        bMessage.setNotDeleted();
//        return bMessageRepository.queryBMessages(bMessage);
//    }

}
