package org.rcisoft.core.util;

import lombok.extern.slf4j.Slf4j;
import org.apache.pdfbox.io.RandomAccessBuffer;
import org.apache.pdfbox.pdfparser.PDFParser;
import org.apache.poi.POIXMLDocument;
import org.apache.poi.hslf.usermodel.HSLFSlideShow;
import org.apache.poi.hwpf.extractor.WordExtractor;
import org.apache.poi.openxml4j.opc.OPCPackage;
import org.rcisoft.core.exception.ServiceException;
import org.rcisoft.core.result.ResultServiceEnums;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;

@Slf4j
public class FileReadableUtil {
    public static void main(String[] args)  {
         String filePath = "C:\\Users\\三\\Desktop\\素材\\2000页.docx";
        fileReadable(filePath);
    }

    public static void fileReadable(String path) {
        LogUtil.fileChangeLog("-----------FileReadableUtil-路径------------"+path);
        File file = new File(path);
        InputStream is = null;
        HSLFSlideShow slideShow = null;
        WordExtractor ex = null;
        RandomAccessBuffer randomAccessBuffer = null;
        OPCPackage opcPackage = null;
        try {
            if (path.endsWith(".doc")) {
                is = new FileInputStream(new File(path));
                ex = new WordExtractor(is);
            }else if (path.endsWith("ppt")) {
                is =new FileInputStream(file);
                slideShow = new HSLFSlideShow(is);
            } else if (path.endsWith("pdf")) {
                is = new FileInputStream(file);
                randomAccessBuffer = new RandomAccessBuffer(is);
                PDFParser parser = new PDFParser(randomAccessBuffer);
                parser.parse();
            }else if (path.endsWith("docx") || path.endsWith("pptx")) {
                opcPackage = POIXMLDocument.openPackage(path);
            }

        } catch (Exception e) {
            log.error("文件不可读---"+e);
            throw new ServiceException(ResultServiceEnums.FILE_UNREADABLE);
        }finally {
            try{
                if(is != null){
                    is.close();
                }
            }catch(Exception e){
                log.error("关闭 InputStream 输出流错误！", e);
            }
            try{
                if(ex != null){
                    ex.close();
                }
            }catch(Exception e){
                log.error("关闭 WordExtractor 输出流错误！", e);
            }
            try{
                if(randomAccessBuffer != null){
                    randomAccessBuffer.close();
                }
            }catch(Exception e){
                log.error("关闭 RandomAccessBuffer 输出流错误！", e);
            }
            try{
                if(opcPackage != null){
                    opcPackage.close();
                }
            }catch(Exception e){
                log.error("关闭 OPCPackage 输出流错误！", e);
            }
            try{
                if(slideShow != null){
                    slideShow.close();
                }
            }catch(Exception e){
                log.error("关闭 HSLFSlideShow 输出流错误！", e);
            }
        }
    }


}
